.. image:: https://raw.githubusercontent.com/LuisAlejandro/pipsalabim/develop/docs/_static/title.svg

-----

.. image:: https://img.shields.io/pypi/v/pipsalabim.svg
   :target: https://pypi.org/project/pipsalabim
   :alt: PyPI Package

.. image:: https://img.shields.io/github/release/LuisAlejandro/pipsalabim.svg
   :target: https://github.com/LuisAlejandro/pipsalabim/releases
   :alt: Github Releases

.. image:: https://img.shields.io/github/issues/LuisAlejandro/pipsalabim
   :target: https://github.com/LuisAlejandro/pipsalabim/issues?q=is%3Aopen
   :alt: Github Issues

.. image:: https://github.com/LuisAlejandro/pipsalabim/workflows/Push/badge.svg
   :target: https://github.com/LuisAlejandro/pipsalabim/actions?query=workflow%3APush
   :alt: Push

.. image:: https://readthedocs.org/projects/pipsalabim/badge/?version=latest
   :target: https://readthedocs.org/projects/pipsalabim/?badge=latest
   :alt: Read The Docs

.. image:: https://img.shields.io/discord/809504357359157288.svg?label=&logo=discord&logoColor=ffffff&color=7389D8&labelColor=6A7EC2
   :target: https://discord.gg/6W6pJKRyAJ
   :alt: Discord Channel

|
|

.. _PyPIContents: https://github.com/LuisAlejandro/pypicontents

Pip Sala Bim is an assistant to guess your pip dependencies from your code, without using a
requirements file.

Pip Sala Bim will tell you which packages you need to install to satisfy the dependencies of
your project. It uses a simple AST visitor for detecting imports and `PyPIContents`_ to
search which packages contain these imports.

* Free software: GPL-3
* Documentation: https://pipsalabim.readthedocs.org

Table of Contents
-----------------

.. toctree::
   :maxdepth: 2

   installation
   usage
   api
   contributing
   authors
   history
   maintainer

Made with 💖 and 🍔
====================

.. image:: https://raw.githubusercontent.com/LuisAlejandro/pipsalabim/develop/docs/_static/author-banner.svg

.. _LuisAlejandroTwitter: https://twitter.com/LuisAlejandro
.. _LuisAlejandroGitHub: https://github.com/LuisAlejandro
.. _luisalejandro.org: https://luisalejandro.org

|

    Web luisalejandro.org_ · GitHub `@LuisAlejandro`__ · Twitter `@LuisAlejandro`__

__ LuisAlejandroGitHub_
__ LuisAlejandroTwitter_
